@@ -36,11 +36,14 @@ class album extends zoph_tree_table {
         if ($user && !$user->is_admin()) {
             $sql =
                  "select a.* from "  .
-                 DB_PREFIX . "albums as a, " .
-                 DB_PREFIX . "album_permissions as ap " .
-                 "where ap.album_id = '" . escape_string($id) . "'" .
-                 " and ap.user_id = '" . escape_string($user->get("user_id")) .
-                 "' and ap.album_id = a.album_id";
+                 DB_PREFIX . "albums as a JOIN " .
+                 DB_PREFIX . "group_permissions as gp ON " .
+                 "gp.album_id = a.album_id JOIN " .
+                 DB_PREFIX . "groups_users gu ON " .
+                 "gp.group_id = gu.group_id " .
+                 "where gp.album_id = '" . escape_string($id) . "'" .
+                 " and gu.user_id = '" . 
+                 escape_string($user->get("user_id"))."'";
         }
         else {
             $sql =
@@ -52,7 +55,7 @@ class album extends zoph_tree_table {
     }
 
     function delete() {
-        parent::delete(array("photo_albums", "album_permissions"));
+        parent::delete(array("photo_albums", "group_permissions"));
         $users = get_records("user", "user_id", array("lightbox_id" => $this->get("album_id")));
         if ($users) {
           foreach ($users as $user) {
@@ -66,12 +69,17 @@ class album extends zoph_tree_table {
         return $this->get("album");
     }
 
-    function get_children($user=null) {
-        if($user) {
-            $user->lookup_prefs();
-            $order = $user->prefs->get("child_sortorder") . ", name";
-        } else {
-            $order = "name";
+    function get_indented_name() {
+        $indent=str_repeat("&nbsp;&nbsp;&nbsp;", count($this->get_ancestors()));
+        return $indent . $this->get_name();
+    }
+
+    function get_children($user=null, $order=null) {
+        if($order && $order!="name") {
+            $order_fields=get_sql_for_order($order);
+            $order=" ORDER BY " . $order . ", name ";
+        } else if ($order=="name") {
+            $order=" ORDER BY name ";
         }
 
         $id = $this->get("album_id");
@@ -79,45 +87,33 @@ class album extends zoph_tree_table {
         
         if ($user && !$user->is_admin()) {
             $sql =
-                "SELECT a.*, album as name, " .
-                "min(p.date) as oldest, " .
-                "max(p.date) as newest, " .
-                "min(p.timestamp) as first, " .
-                "max(p.timestamp) as last, " .
-                "min(rating) as lowest, " . 
-                "max(rating) as highest, " .
-                "avg(rating) as average, " .
-                "rand() as random from " .
-                DB_PREFIX . "albums as a JOIN " .
-                DB_PREFIX . "photo_albums as pa " .
-                "ON a.album_id=pa.album_id LEFT JOIN " .
-                DB_PREFIX . "photos as p " .
-                "ON pa.photo_id=p.photo_id LEFT JOIN " .
-                DB_PREFIX . "album_permissions ap " .
-                "ON a.album_id=ap.album_id " .
-                "WHERE user_id=" . $user->get("user_id") .
-                " AND parent_album_id=" . escape_string($id) .
-                " GROUP BY a.album_id " .
-                "ORDER BY " . escape_string($order);
-        } else {
+        "SELECT a.*, album as name " .
+            $order_fields . " FROM " .
+            DB_PREFIX . "albums as a LEFT JOIN " .
+            DB_PREFIX . "photo_albums as pa " .
+            "ON a.album_id=pa.album_id LEFT JOIN " .
+            DB_PREFIX . "photos as ph " .
+            "ON pa.photo_id=ph.photo_id LEFT JOIN " .
+            DB_PREFIX . "group_permissions AS gp " .
+            "ON a.album_id=gp.album_id JOIN " .
+            DB_PREFIX . "groups_users AS gu ON " .
+            "gp.group_id = gu.group_id " .
+            "WHERE gu.user_id=" . escape_string($user->get("user_id")) .
+            " AND parent_album_id=" . escape_string($id) .
+            " GROUP BY album_id" .
+            escape_string($order);
+         } else {
             $sql =
-                "SELECT a.*, album as name, " .
-                "min(p.date) as oldest, " .
-                "max(p.date) as newest, " .
-                "min(p.timestamp) as first, " .
-                "max(p.timestamp) as last, " .
-                "min(rating) as lowest, " . 
-                "max(rating) as highest, " .
-                "avg(rating) as average, " .
-                "rand() as random from " .
+                "SELECT a.*, album as name " .
+                $order_fields . " FROM " .
                 DB_PREFIX . "albums as a LEFT JOIN " .
                 DB_PREFIX . "photo_albums as pa " .
                 "ON a.album_id=pa.album_id LEFT JOIN " .
-                DB_PREFIX . "photos as p " .
-                "ON pa.photo_id=p.photo_id " .
+                DB_PREFIX . "photos as ph " .
+                "ON pa.photo_id=ph.photo_id " .
                 "WHERE parent_album_id=" . escape_string($id) .
-                " GROUP BY a.album_id " .
-                "ORDER BY " . escape_string($order);
+                " GROUP BY album_id" .
+                escape_string($order);
         }
 
         $this->children=get_records_from_query("album", $sql);
@@ -132,14 +128,16 @@ class album extends zoph_tree_table {
         if ($user && !$user->is_admin()) {
             $sql =
                 "select count(*) from " .
-                DB_PREFIX . "photo_albums as pa, " .
-                DB_PREFIX . "photos as p, " .
-                DB_PREFIX . "album_permissions as ap " .
-                "where pa.album_id = " . escape_string($id) .
-                " and ap.user_id = '" . escape_string($user->get("user_id")) .
-                "' and ap.album_id = pa.album_id" .
-                " and pa.photo_id = p.photo_id " .
-                " and ap.access_level >= p.level";
+                DB_PREFIX . "photo_albums AS pa JOIN " .
+                DB_PREFIX . "photos AS p ON " .
+                "pa.photo_id = p.photo_id JOIN " .
+                DB_PREFIX . "group_permissions AS gp ON " .
+                "gp.album_id = pa.album_id JOIN " .
+                DB_PREFIX . "groups_users AS gu ON " .
+                "gp.group_id = gu.group_id " .
+                "WHERE pa.album_id = " . escape_string($id) .
+                " and gu.user_id = '" . escape_string($user->get("user_id")) .
+                "' and gp.access_level >= p.level";
         }
         else {
             $sql =
@@ -164,13 +162,15 @@ class album extends zoph_tree_table {
         if ($user && !$user->is_admin()) {
             $sql =
                 "select count(distinct pa.photo_id) from " .
-                DB_PREFIX . "photo_albums as pa, " .
-                DB_PREFIX . "photos as p, " .
-                DB_PREFIX . "album_permissions as ap " .
-                "where ap.user_id = '" . escape_string($user->get("user_id")) .
-                "' and ap.album_id = pa.album_id " .
-                " and pa.photo_id = p.photo_id " .
-                " and ap.access_level >= p.level";
+                DB_PREFIX . "photo_albums as pa JOIN " .
+                DB_PREFIX . "photos as p ON " .
+                "pa.photo_id = p.photo_id JOIN " .
+                DB_PREFIX . "group_permissions as gp ON " .
+                "pa.album_id = gp.album_id JOIN " .
+                DB_PREFIX . "groups_users AS gu ON " .
+                "gp.group_id = gu.group_id " .
+                "WHERE gu.user_id = '" . escape_string($user->get("user_id")) .
+                "' and gp.access_level >= p.level";
 
             if ($id_constraint) {
                 $sql .= " and $id_constraint";
@@ -189,7 +189,7 @@ class album extends zoph_tree_table {
         return get_count_from_query($sql);
     }
 
-    function get_edit_array() {
+    function get_edit_array($user) {
         if($this->is_root()) {
             $parent=array (
                 translate("parent album"),
@@ -197,8 +197,8 @@ class album extends zoph_tree_table {
         } else {
             $parent=array (
                 translate("parent album"),
-                create_pulldown("parent_album_id",
-                $this->get("parent_album_id"), get_albums_select_array()));
+                create_album_pulldown("parent_album_id",
+                $this->get("parent_album_id"), $user));
         }
         return array(
             "album" => 
@@ -214,7 +214,7 @@ class album extends zoph_tree_table {
             "pageset" =>
                 array(
                     translate("pageset"),
-                    create_smart_pulldown("pageset", $this->get("pageset"), get_pageset_select_array())),
+                    create_pulldown("pageset", $this->get("pageset"), get_pageset_select_array())),
             "sortname" =>
                 array(
                     translate("sort name"),
@@ -267,13 +267,15 @@ class album extends zoph_tree_table {
                     DB_PREFIX . "photos as p JOIN " .
                     DB_PREFIX . "photo_albums as pa" .
                     " ON pa.photo_id = p.photo_id JOIN " .
-                    DB_PREFIX . "album_permissions as ap " .
-                    " ON pa.album_id = ap.album_id" .
+                    DB_PREFIX . "group_permissions as gp ON " .
+                    "pa.album_id = gp.album_id JOIN " .
+                    DB_PREFIX . "groups_users AS gu ON " .
+                    "gp.group_id = gu.group_id " .
                     $album_where .
-                    " AND ap.user_id =" . 
+                    " AND gu.user_id =" . 
                     " '" . escape_string($user->get("user_id")) . "'" .
                     " and pa.photo_id = p.photo_id " .
-                    " and ap.access_level >= p.level " .
+                    " and gp.access_level >= p.level " .
                     $order;
             } else {
                 $sql =
@@ -318,10 +320,11 @@ function get_albums($user = null) {
     if ($user && !$user->is_admin()) {
         $sql =
              "select a.* from " .
-             DB_PREFIX . "albums as a, " .
-             DB_PREFIX . "album_permissions as ap " .
-             "where ap.user_id = '" . escape_string($user->get("user_id")) .
-             "' and ap.album_id = a.album_id " .
+             DB_PREFIX . "albums as a JOIN " .
+             DB_PREFIX . "group_permissions AS gp " .
+             "ON gp.album_id = a.album_id JOIN " .
+             DB_PREFIX . "groups_users as gu " .
+             "where gu.user_id = '" . escape_string($user->get("user_id")) .
              "order by a.album";
     }
     else {
@@ -333,12 +336,13 @@ function get_albums($user = null) {
 
 function get_newer_albums($user_id, $date = null) {
     $sql = "select a.* from " .
-        DB_PREFIX . "albums as a, " .
-        DB_PREFIX . "album_permissions as ap " .
-        "where ap.user_id = '" . escape_string($user_id) .
-        "' and ap.album_id = a.album_id " .
-        "and ap.changedate > '" . escape_string($date) . "' " .
-        "order by a.album_id";
+        DB_PREFIX . "albums as a JOIN " .
+        DB_PREFIX . "group_permissions as gp " .
+        "ON a.album_id = gp.album_id JOIN " .
+        DB_PREFIX . "groups_users as gu " .
+        "WHERE gu.user_id = '" . escape_string($user_id) .
+        "' AND gp.changedate > '" . escape_string($date) . "' " .
+        "ORDER BY a.album_id";
 
     return get_records_from_query("album", $sql);
 }
@@ -360,8 +364,11 @@ function get_album_count($user = null) {
 
     if ($user && !$user->is_admin()) {
         $sql =
-            "select count(*) from " . DB_PREFIX . "album_permissions " .
-            "where user_id = '" . escape_string($user->get("user_id")) . "'";
+            "SELECT COUNT(DISTINCT album_id) FROM " . 
+            DB_PREFIX . "group_permissions AS gp JOIN " .
+            DB_PREFIX . "groups_users AS gu ON " .
+            "gp.group_id = gu.group_id " .
+            "where gu.user_id = '" . escape_string($user->get("user_id")) . "'";
     }
     else {
         $sql = "select count(*) from " . DB_PREFIX . "albums";
@@ -384,19 +391,21 @@ function get_popular_albums($user) {
 
     if ($user && !$user->is_admin()) {
         $sql =
-            "select al.*, count(distinct ph.photo_id) as count from " .
-            DB_PREFIX . "albums as al, " .
-            DB_PREFIX . "photos as ph, " .
-            DB_PREFIX . "photo_albums as pa, " .
-            DB_PREFIX . "album_permissions as ap " .
-            "where ap.user_id = '" . escape_string($user->get("user_id")) . "'" .
-            " and ap.album_id = pa.album_id" .
-            " and pa.album_id = al.album_id" .
-            " and pa.photo_id = ph.photo_id" .
-            " and ap.access_level >= ph.level " .
-            "group by al.album_id " .
-            "order by count desc, al.album " .
-            "limit 0, " . escape_string($TOP_N);
+            "SELECT al.*, count(distinct ph.photo_id) AS count FROM " .
+            DB_PREFIX . "albums AS al JOIN " .
+            DB_PREFIX . "photo_albums AS pa ON " .
+            " al.album_id = pa.album_id JOIN " .
+            DB_PREFIX . "photos AS ph ON " .
+            "pa.photo_id = ph.photo_id JOIN " .
+            DB_PREFIX . "group_permissions AS gp ON " .
+            "pa.album_id = gp.album_id JOIN " .
+            DB_PREFIX . "groups_users AS gu ON " .
+            "gp.group_id = gu.group_id " .
+            "WHERE gu.user_id = '" . escape_string($user->get("user_id")). "'" .
+            " AND gp.access_level >= ph.level " .
+            "GROUP BY al.album_id " .
+            "ORDER BY count desc, al.album " .
+            "LIMIT 0, " . escape_string($TOP_N);
     }
     else {
         $sql =
@@ -413,4 +422,22 @@ function get_popular_albums($user) {
 
 }
 
+function create_album_pulldown($name, $value=null, $user=null) {
+    $id=ereg_replace("^_+", "", $name);
+    if($value) {
+        $album=new album($value);
+        $album->lookup();
+        $text=$album->get("album");
+    } 
+    
+    if($user->prefs->get("autocomp_albums") && AUTOCOMPLETE && JAVASCRIPT) {
+        $html="<input type=hidden id='" . $id . "' name='" . $name. "'" .
+            " value='" . $value . "'>";
+        $html.="<input type=text id='_" . $id . "' name='_" . $name. "'" .
+            " value='" . $text . "' class='autocomplete'>";
+    } else {
+        $html=create_pulldown($name, $value, get_albums_search_array($user));
+    }
+    return $html;
+}
 ?>
