@@ -50,11 +50,12 @@
     $page=$page[0];
     
     if (!isset($skipcrumb) && $title && count($user->crumbs) < MAX_CRUMBS &&
-        (!$_action || ($_action == "display" || $_action == "search" ||
+        (!$_action || ($_action == "display" || 
+        $_action == "search" || $_action == translate("search") ||
         $_action == "notify" || $_action == "compose" || 
-        ($user->prefs->get("auto_edit") && $_action != "update"
-        && $_action != "select" && $_action != "deselect"
-        && $page == "photo.php")))) {
+        ($user->prefs->get("auto_edit") && $_action != "update" &&
+        $_action != "select" && $_action != "deselect" &&
+        $_action != "delrate" && $page == "photo.php")))) {
 
         $user->add_crumb($title, htmlentities($REQUEST_URI));
     }
