@@ -37,39 +37,36 @@ class category extends zoph_tree_table {
         return $this->get("category");
     }
 
-    function get_children($user=null) {
-        if($user) {
-            $order = $user->prefs->get("child_sortorder") . ", name";
-        } else {
-            $order = "name";
+    function get_children($user=null,$order=null) {
+        if($order && $order!="name") {
+            $order_fields=get_sql_for_order($order);
+            $order=" ORDER BY " . $order . ", name ";
+        } else if ($order=="name") {
+            $order=" ORDER BY name ";
         }
+
         $id = $this->get("category_id");
         if (!$id) { return; }
 
         $sql =
-            "SELECT c.*, category as name, " .
-            "min(p.date) as oldest, " .
-            "max(p.date) as newest, " .
-            "min(p.timestamp) as first, " .
-            "max(p.timestamp) as last, " .
-            "min(rating) as lowest, " . 
-            "max(rating) as highest, " .
-            "avg(rating) as average, " .
-            "rand() as random from " .
+            "SELECT c.*, category as name " .
+            $order_fields . " FROM " .
             DB_PREFIX . "categories as c LEFT JOIN " .
             DB_PREFIX . "photo_categories as pc " .
             "ON c.category_id=pc.category_id LEFT JOIN " .
-            DB_PREFIX . "photos as p " .
-            "ON pc.photo_id=p.photo_id " .
+            DB_PREFIX . "photos as ph " .
+            "ON pc.photo_id=ph.photo_id " .
             "WHERE parent_category_id=" . $id .
             " GROUP BY c.category_id " .
-            "ORDER BY " . $order;
+            $order;
         $this->children=get_records_from_query("category", $sql);
-        return $this->children;
+        if($user && !$user->is_admin()) {
+            return(remove_empty($this->children,$user));
+        } else {
+            return $this->children;
+        }
     }    
-
-   // }
-
+    
     function get_branch_ids($user = null) {
         return parent::get_branch_ids($user);
     }
@@ -84,14 +81,16 @@ class category extends zoph_tree_table {
                 "select count(distinct pc.photo_id) from " .
                 DB_PREFIX . "photo_categories as pc JOIN " .
                 DB_PREFIX . "photo_albums as pa " .
-                " ON pc.photo_id = pa.photo_id JOIN " .
+                "ON pc.photo_id = pa.photo_id JOIN " .
                 DB_PREFIX . "photos as p " .
-                " ON pa.photo_id = p.photo_id JOIN " .
-                DB_PREFIX . "album_permissions as ap " .
-                " ON pa.album_id = ap.album_id " .
-                "where pc.category_id = '" .  escape_string($id) . "'" .
-                " and ap.user_id = '" . escape_string($user->get("user_id")) . "'" .
-                " and ap.access_level >= p.level";
+                "ON pa.photo_id = p.photo_id JOIN " .
+                DB_PREFIX . "group_permissions as gp " .
+                "ON pa.album_id = gp.album_id JOIN " .
+                DB_PREFIX . "groups_users as gu " .
+                "ON gp.group_id = gu.group_id " .
+                "WHERE pc.category_id = '" .  escape_string($id) . "' " .
+                "AND gu.user_id = '" . escape_string($user->get("user_id")) . 
+                "' AND gp.access_level >= p.level";
         }
         else {
             $sql =
@@ -118,13 +117,15 @@ class category extends zoph_tree_table {
                 "select count(distinct pc.photo_id) from " .
                 DB_PREFIX . "photo_categories as pc JOIN " .
                 DB_PREFIX . "photo_albums as pa " .
-                " ON pc.photo_id = pa.photo_id JOIN " .
+                "ON pc.photo_id = pa.photo_id JOIN " .
                 DB_PREFIX . "photos as p " .
-                " ON pa.photo_id = p.photo_id JOIN " .
-                DB_PREFIX . "album_permissions as ap " .
-                " ON pa.album_id = ap.album_id" .
-                " where ap.user_id = '" . escape_string($user->get("user_id")) . "'" .
-                " and ap.access_level >= p.level";
+                "ON pa.photo_id = p.photo_id JOIN " .
+                DB_PREFIX . "group_permissions as gp " .
+                "ON pa.album_id = gp.album_id JOIN " .
+                DB_PREFIX . "groups_users as gu " .
+                "ON gp.group_id = gu.group_id " .
+                "WHERE gu.user_id = '" . escape_string($user->get("user_id")) .
+                "' AND gp.access_level >= p.level";
 
             if ($id_constraint) {
                 $sql .= " and $id_constraint";
@@ -143,7 +144,7 @@ class category extends zoph_tree_table {
         return get_count_from_query($sql);
     }
 
-    function get_edit_array() {
+    function get_edit_array($user) {
         if($this->is_root()) {
             $parent=array(
                 translate("parent category"),
@@ -151,9 +152,9 @@ class category extends zoph_tree_table {
         } else {
             $parent=array(
                 translate("parent category"),
-                create_pulldown("parent_category_id",
+                create_cat_pulldown("parent_category_id",
                     $this->get("parent_category_id"),
-                    get_categories_select_array()));
+                    $user));
         }
         return array(
             "category" =>
@@ -169,7 +170,7 @@ class category extends zoph_tree_table {
             "pageset" =>
                 array(
                     translate("pageset"),
-                    create_smart_pulldown("pageset", $this->get("pageset"), get_pageset_select_array())),
+                    create_pulldown("pageset", $this->get("pageset"), get_pageset_select_array())),
             "sortname" =>
                 array(
                     translate("sort name"),
@@ -218,16 +219,18 @@ class category extends zoph_tree_table {
                 $sql=
                     "select distinct p.photo_id from " .
                     DB_PREFIX . "photos as p JOIN " .
-                    DB_PREFIX . "photo_albums as pa" .
-                    " ON pa.photo_id = p.photo_id JOIN " .
-                    DB_PREFIX . "album_permissions as ap " .
-                    " ON pa.album_id = ap.album_id JOIN " .
+                    DB_PREFIX . "photo_albums as pa " .
+                    "ON pa.photo_id = p.photo_id JOIN " .
+                    DB_PREFIX . "group_permissions as gp " .
+                    "ON pa.album_id = gp.album_id JOIN " .
+                    DB_PREFIX . "groups_users as gu " .
+                    "ON gp.group_id = gu.group_id JOIN " .
                     DB_PREFIX . "photo_categories as pc " .
-                    " ON pc.photo_id = p.photo_id " .
+                    "ON pc.photo_id = p.photo_id " .
                     $cat_where .
-                    " AND ap.user_id =" .
+                    " AND gu.user_id =" .
                     " '" . escape_string($user->get("user_id")) . "'" .
-                    " and ap.access_level >= p.level " .
+                    " AND gp.access_level >= p.level " .
                     $order;
             } else {
                 $sql =
@@ -295,20 +298,23 @@ function get_popular_categories($user) {
     if ($user && !$user->is_admin()) {
         $sql =
             "select cat.*, count(distinct ph.photo_id) as count from " .
-            DB_PREFIX . "categories as cat, " .
-            DB_PREFIX . "photo_categories as pc, " .
-            DB_PREFIX . "photos as ph, " .
-            DB_PREFIX . "photo_albums as pa, " .
-            DB_PREFIX . "album_permissions as ap " .
-            "where ap.user_id = '" . escape_string($user->get("user_id")) . "'" .
-            " and ap.album_id = pa.album_id" .
-            " and pa.photo_id = pc.photo_id" .
-            " and pc.category_id = cat.category_id" .
-            " and pc.photo_id = ph.photo_id" .
-            " and ap.access_level >= ph.level " .
-            "group by cat.category_id " .
-            "order by count desc, cat.category " .
-            "limit 0, " . escape_string($TOP_N);
+            DB_PREFIX . "categories as cat JOIN " .
+            DB_PREFIX . "photo_categories as pc ON " .
+            "pc.category_id = cat.category_id JOIN " .
+            DB_PREFIX . "photos as ph ON " .
+            " pc.photo_id = ph.photo_id JOIN " .
+            DB_PREFIX . "photo_albums as pa ON " .
+            " pa.photo_id = pc.photo_id JOIN " .
+            DB_PREFIX . "group_permissions as gp ON " .
+            "pa.album_id = gp.album_id JOIN " .
+            DB_PREFIX . "groups_users as gu ON " .
+            "gp.group_id = gu.group_id " .
+            "WHERE gu.user_id = '" . 
+            escape_string($user->get("user_id")) . "'" .
+            "AND gp.access_level >= ph.level " .
+            "GROUP BY cat.category_id " .
+            "ORDER BY count desc, cat.category " .
+            "LIMIT 0, " . escape_string($TOP_N);
     }
     else {
         $sql =
@@ -325,4 +331,36 @@ function get_popular_categories($user) {
 
 }
 
+function create_cat_pulldown($name, $value=null, $user) {
+    $id=ereg_replace("^_+", "", $name);
+    if($value) {
+        $cat=new category($value);
+        $cat->lookup();
+        $text=$cat->get("category");
+    }
+    if($user->prefs->get("autocomp_categories") && AUTOCOMPLETE && JAVASCRIPT) {
+        $html="<input type=hidden id='" . $id . "' name='" . $name. "'" .
+            " value='" . $value . "'>";
+        $html.="<input type=text id='_" . $id . "' name='_" . $name. "'" .
+            " value='" . $text . "' class='autocomplete'>";
+    } else {
+        $html=create_pulldown($name, $value, get_categories_search_array($user));
+    }
+    return $html;
+}
+
+function get_category_count($user) {
+    if($user && !$user->is_admin()) {
+        $sql =
+            "SELECT category_id, parent_category_id  FROM " .
+            DB_PREFIX . "categories as c";
+        $cats=get_records_from_query("category", $sql);
+        $cat_clean=remove_empty($cats,$user);
+        return count($cat_clean);
+    } else {
+        return get_count("category");
+    }
+}
+ 
+
 ?>
