@@ -113,8 +113,8 @@ ul.thumbs li {
     position: relative;
     display: block;
     text-align: center;
-    width: 160px;
-    height: 180px;
+    width: <?php echo THUMB_SIZE + 20 ?>px;
+    height:<?php echo THUMB_SIZE + 40 ?>px;
     float:left;
     margin: 5px;
     padding: 5px;
@@ -125,7 +125,7 @@ ul.thumbs li p {
     display: block;
     margin-left: auto;
     margin-right: auto;
-    min-height: 120px;
+    width: <?php echo THUMB_SIZE ?>px;
     }
 
 ul.thumbs li img {
@@ -374,7 +374,7 @@ div.breadcrumb li.firstdots:before {
     }
 
 /* Main page */
-.main, .info, .letter, .page, div.map, div#selection   {
+.main, .info, .letter, .page, div.map, div#selection, .warning   {
     background: <?php echo $TABLE_BG_COLOR ?>;
     font-size: medium;
     width: 100%;
@@ -384,6 +384,15 @@ div.breadcrumb li.firstdots:before {
     clear: both;
     }
 
+div.warning {
+    background: #ffffcc;
+}
+
+div.warning img.icon {
+    float: left;
+    margin-right: 10px;
+}
+
 div.map {
     height: 450px;
     }
@@ -410,7 +419,7 @@ span.showhide {
     text-align: right;
     }
 
-div.timedetail {
+div.timedetail, div.ratingdetail {
     display: none;
     border: 1px solid <?php echo $TABLE_BORDER_COLOR ?>;
     background: white;
@@ -430,6 +439,23 @@ div.timedetail h3 {
     color: <?php echo $TITLE_FONT_COLOR ?>;
     font-size: large;
 }
+
+table.ratingdetail {
+    border-collapse: collapse;
+    width: 100%;
+}
+
+table.ratingdetail td, table.ratingdetail th {
+    text-align: left;
+    font-size: small;
+    padding: 2px;
+}
+
+table.ratingdetail th {
+    background: <?php echo $TITLE_BG_COLOR ?>;
+    color: <?php echo $TITLE_FONT_COLOR ?>;
+}
+
 p.main, p.info {
     padding: 4px;
     }
@@ -501,9 +527,14 @@ div.smileys img {
 /* This is the bar that shows the number of photos for each rating */
 div.ratings   {
     float: left;
+    border: 1px solid <?php echo $TABLE_BORDER_COLOR ?>;
     background: <?php echo $BREADCRUMB_BG_COLOR ?>;
     }
 
+table#search td {
+    vertical-align: top;
+    }
+
 table#search input[type="checkbox"] {
     float: none;
     }
@@ -516,7 +547,7 @@ table#search input[type="checkbox"] + label {
     font-weight: normal;
     margin: 3px;
     padding: 0;
-    top: 8px;
+    top: 3px;
     width: auto;
     clear: none;
     }
@@ -604,7 +635,7 @@ div.color {
 
 /* Tables for the permissions */
 
-table#permissions   {
+table.permissions   {
     background: <?php echo $TABLE_BG_COLOR ?>;
     width: 90%;
     margin-left: auto; /* To center the page */
@@ -613,27 +644,27 @@ table#permissions   {
     font-size: medium;
     }   
 
-table#permissions td, table#permissions th  {
+table.permissions td, table.permissions th  {
     background: <?php echo $TABLE_BG_COLOR ?>;
     font-size: medium;
     }
 
-table#permissions col {
+table.permissions col {
     text-align: center; 
     padding: 0px;
     }
 
-table#permissions > col.col1 { 
+table.permissions > col.col1 { 
     padding-left: 15px; 
     text-align: left; 
     width: 5%;
     }
     
-table#permissions > col.col2 { width: 55%; text-align: left; }
-table#permissions > col.col3 { width: 20%; text-align: center; }
-table#permissions > col.col4 { width: 20%; text-align: center;}
+table.permissions > col.col2 { width: 55%; text-align: left; }
+table.permissions > col.col3 { width: 20%; text-align: center; }
+table.permissions > col.col4 { width: 20%; text-align: center;}
 
-table#permissions td.permremove {
+table.permissions td.permremove {
     padding-top: 3px;
     padding-bottom: 0px;
     font-size: x-small;
@@ -797,6 +828,10 @@ div.commentinfo {
     padding: 0;
     }
 
+span.searchinfo {
+    font-size: x-small;
+    }
+
 br  {
     clear: both;
     }
@@ -872,6 +907,18 @@ dl#allexif dl {
     width: 100%
     }
 
+dl.groups dt {
+    margin-top: 0;
+    margin-bottom: 10px;
+    width: 20%;
+    }
+
+dl.groups dd {
+    margin-top: 2px;
+    width: 40%;
+    font-size: small;
+    }
+    
 label, table.credits th {
     text-align: right;
     vertical-align: top;
