@@ -29,7 +29,7 @@
     require_once("include.inc.php");
 
     if (!ANNOTATE_PHOTOS) {
-        header("Location: " . add_sid("zoph.php"));
+        redirect(add_sid("zoph.php"));
     }
 
     $title = translate("Annotate Photo");
