@@ -27,7 +27,7 @@
     }
 
     if (!$user->is_admin() && !$user->get("browse_people")) {
-        header("Location: " . add_sid("zoph.php"));
+        redirect(add_sid("zoph.php"));
     }
 
     $_l = getvar("_l");
@@ -118,7 +118,7 @@
     }
     else {
 ?>
-          <div class="error"><?php echo sprintf(translate("No people were found with a last name beginning with '%s'."), $_l) ?></div>
+          <div class="error"><?php echo sprintf(translate("No people were found with a last name beginning with '%s'."), htmlentities($_l)) ?></div>
 <?php
     }
 ?>
