@@ -208,7 +208,7 @@ function get_people_count($user = null, $search = null) {
             $allowed[]=$person->get("person_id");
         }
         foreach($photographers as $photographer) {
-            $allowed[]=$person->get("person_id");
+            $allowed[]=$photographer->get("person_id");
         }
 
         $allowed=array_unique($allowed);
@@ -229,7 +229,7 @@ function get_all_people($user = null, $search = null, $search_first = false) {
             $allowed[]=$person->get("person_id");
         }
         foreach($photographers as $photographer) {
-            $allowed[]=$person->get("person_id");
+            $allowed[]=$photographer->get("person_id");
         }
 
         $allowed=array_unique($allowed);
@@ -336,7 +336,7 @@ function get_people_select_array($people_array = null, $user = null) {
     $ppl[""] = "";
 
     if (!$people_array) {
-        $people_array = get_people(null,null,null,null,$user);
+        $people_array = get_people(null,null,null,"last_name, first_name",$user);
     }
     if ($people_array) {
         foreach ($people_array as $person) {
@@ -462,7 +462,7 @@ function create_photographer_pulldown($name, $value=null, $user) {
         $html.="<input type=text id='_" . $id . "' name='_" . $name. "'" .
             " value='" . $text . "' class='autocomplete'>";
     } else {
-        $html=create_pulldown($name, $value, get_photographer_search_array($user));
+        $html=create_pulldown($name, $value, get_people_select_array(null, $user));
     }
     return $html;
 }
