@@ -470,7 +470,11 @@ return "<img src=\"$image_href\" class=\"" . $type . "\" " . $size_string . " al
         $row = fetch_array($result);
 
         $avg = (round(100 * $row[0])) / 100.0;
-
+        
+        if($avg == 0) {
+            $avg = "null";
+        }
+      
         $query = "update " . DB_PREFIX . "photos set rating = $avg" .
             " where photo_id = '" . escape_string($photo_id) . "'";
 
@@ -856,7 +860,8 @@ echo ("<br>\noutString:<br>\n" . $out_string);
     }
 
     function get_display_array() {
-        $datetime=$this->get_time();
+        $datetime=$this->get_time(null, "Y-m-d");
+
         return array(
             translate("title") => $this->get("title"),
             translate("location") => $this->location
@@ -911,7 +916,7 @@ echo ("<br>\noutString:<br>\n" . $out_string);
             "Level" => create_text_input("level", $this->level, 4, 2));
     }
 
-    function get_time($timezone=null) {
+    function get_time($timezone=null, $date_format=DATE_FORMAT, $time_format=TIME_FORMAT) { 
         if(minimum_version("5.1.0")) {
             if(valid_tz($timezone)) {
                 $place_tz=new TimeZone($timezone);
@@ -932,6 +937,10 @@ echo ("<br>\noutString:<br>\n" . $out_string);
             } else if ($place_tz && !$camera_tz) {
                 // Place timezone is known, camera timezone is not.
                 $camera_tz=$place_tz;
+            } else if (!$place_tz && !$camera_tz) {
+                // Neither are set
+                $camera_tz=new TimeZone(date_default_timezone_get());
+                $place_tz=$camera_tz;
             }
             
             $camera_time=new Time(
@@ -945,8 +954,8 @@ echo ("<br>\noutString:<br>\n" . $out_string);
                 $place_time->modify($corr . " minutes");
             }
             
-            $date=$place_time->format(DATE_FORMAT);
-            $time=$place_time->format(TIME_FORMAT);
+            $date=$place_time->format($date_format);
+            $time=$place_time->format($time_format);
         } else {
             // Timezone support was introduced in PHP 5.1
             // so we'll just return date and time as they are
@@ -960,9 +969,9 @@ echo ("<br>\noutString:<br>\n" . $out_string);
     function get_time_details($content, $open=false) {
         $html="&nbsp;";
         if ($open) {
-            $html.="<span onclick=\"unbranch(this)\">-&nbsp;</span>";
+            $html.="<span onclick=\"collapse(this)\">-&nbsp;</span>";
         } else {
-            $html.="<span onclick=\"branch(this)\">+&nbsp;</span>";
+            $html.="<span onclick=\"expand(this)\">+&nbsp;</span>";
         }
         $html.="<span class='showhide'>" . $content . "</span>";
         $html.="<div class='timedetail'>\n<dl>\n";
@@ -1016,9 +1025,9 @@ echo ("<br>\noutString:<br>\n" . $out_string);
         
         $html="&nbsp;";
         if ($open) {
-            $html.="<span onclick=\"unbranch(this)\">-&nbsp;</span>";
+            $html.="<span onclick=\"collapse(this)\">-&nbsp;</span>";
         } else {
-            $html.="<span onclick=\"branch(this)\">+&nbsp;</span>";
+            $html.="<span onclick=\"expand(this)\">+&nbsp;</span>";
         }
         $html.="<span class='showhide'>" . $content . "</span>";
         $html.="<div class='ratingdetail'>\n";
