@@ -31,7 +31,7 @@
 
     $_qs=getvar("_qs");
     if($user->prefs->get("auto_edit") && $_qs && $_action == "update") {
-        header("Location: photo.php?" . $_qs);
+        redirect("photo.php?" . $_qs, "Auto edit");
     }
 
     $qs = preg_replace('/_crumb=\d+&?/', '', $QUERY_STRING);
@@ -60,15 +60,18 @@
         if  ($num_thumbnails) {
             $photo = $thumbnails[0];
             $photo_id = $photo->get("photo_id");
+            if(isset($_action) && !$_action=="" ) {
+                $act="_action=" . $_action . "&";
+            }
 
             if ($offset > 0) {
                 $newoffset = $offset - 1;
-                $prev_link = "<a href=\"" . $PHP_SELF . "?_action=" . $_action . "&" . htmlentities(str_replace("_off=$offset", "_off=$newoffset", $qs)) . "\">" . translate("Prev") . "</a>";
+                $prev_link = "<a href=\"" . $PHP_SELF . "?" . $act . htmlentities(str_replace("_off=$offset", "_off=$newoffset", $qs)) . "\">" . translate("Prev") . "</a>";
             }
 
             if ($offset + 1 < $num_photos) {
                 $newoffset = $offset + 1;
-                $next_link = "<a href=\"" . $PHP_SELF . "?_action=" . $_action . "&" . htmlentities(str_replace("_off=$offset", "_off=$newoffset", $qs)) . "\">" . translate("Next") . "</a>";
+                $next_link = "<a href=\"" . $PHP_SELF . "?" . $act . htmlentities(str_replace("_off=$offset", "_off=$newoffset", $qs)) . "\">" . translate("Next") . "</a>";
             }
         }
         else {
@@ -120,7 +123,7 @@
             $photo->rate($user, $rating);
             $link = strip_href($user->get_last_crumb());
             if (!$link) { $link = "zoph.php"; }
-            header("Location: " . add_sid($link));
+            redirect(add_sid($link));
         }
         $action = "display";
     } else if ($_action == "delrate" && $user->is_admin()) {
@@ -128,7 +131,7 @@
         $photo->delete_rating($rating_id);
         $link = strip_href($user->get_last_crumb());
         if (!$link) { $link = "zoph.php"; }
-        header("Location: " . add_sid($link));
+        redirect(add_sid($link));
     }
 
 
@@ -137,12 +140,12 @@
             $_action == "delete" || $_action == "confirm") {
             // only an admin can do these
             $_action = "display"; // in case redirect fails
-            header("Location: " . add_sid("zoph.php"));
+            redirect(add_sid("zoph.php"));
         }
 
         if (!$permissions) {
             $photo = new photo(-1); // in case redirect fails
-            header("Location: " . add_sid("zoph.php"));
+            redirect(add_sid("zoph.php"));
         }
         else if ($permissions->get("writable") == 0) {
             $_action = "display";
@@ -225,7 +228,7 @@
         //}
         $link = strip_href($user->get_last_crumb());
         if (!$link) { $link = "zoph.php"; }
-        header("Location: " . add_sid($link));
+        redirect(add_sid($link), "Go back");
     } else if ($_action == "select") {
         $sel_key=false;
         if(is_array($_SESSION["selected_photo"])) {
@@ -242,7 +245,7 @@
         if($sel_key !== false) {
             unset($_SESSION["selected_photo"][$sel_key]);
         }
-        header("Location: " . $return . "?" . html_entity_decode(urldecode($_qs)));
+        redirect($return . "?" . html_entity_decode(urldecode($_qs)), "Redirect");
     // 2005-04-10 --JCT
     //
     // lightbox and rate actions moved
@@ -477,12 +480,14 @@ require_once("edit_photo.inc.php");
 ?>
 </div>
 <?php
-      if(JAVASCRIPT && MAPS && $_action=="display") {
+      if(JAVASCRIPT && MAPS && ($_action=="display" || $_action==="")) {
 ?>
         <div id="map" class="map"></div>
 <?php
+        $array=$photo->get_near(100);
+        $array[]=$photo;
         echo create_map_js();
-        echo get_markers($photo->get_near(100), $user);
+        echo get_markers($array, $user);
       }
 ?>
 
