@@ -36,16 +36,16 @@ function get_photos($vars, $offset, $rows, &$thumbnails, $user = null) {
     $from_clause=DB_PREFIX . "photos as ph";
 
     if ($user && !$user->is_admin()) {
-//        $from["pa"] = "photo_albums";
-//        $from["ap"] = "album_permissions";
         $from_clause .= " JOIN " . DB_PREFIX . "photo_albums AS pa " .
-            "ON ph.photo_id = pa.photo_id " .
-            "JOIN " . DB_PREFIX . "album_permissions AS ap " .
-            "ON pa.album_id = ap.album_id ";
+            "ON ph.photo_id = pa.photo_id JOIN " .
+            DB_PREFIX . "group_permissions as gp " .
+            "ON pa.album_id = gp.album_id JOIN " .
+            DB_PREFIX . "groups_users as gu " .
+            "ON gp.group_id = gu.group_id ";
 
         $where =
-             " ap.user_id = '" . escape_string($user->get("user_id")) . "'" .
-             " AND (ap.access_level >= ph.level)";
+             " gu.user_id = '" . escape_string($user->get("user_id")) . "'" .
+             " AND (gp.access_level >= ph.level)";
     }
     else {
         $where = "";
@@ -104,8 +104,11 @@ function get_photos($vars, $offset, $rows, &$thumbnails, $user = null) {
             { die ("Illegal operator: " . $op); }
 
         if (!empty($vars[$index . "-children"])) {
-            $val_no_children=split(",",$val);
-            $val=$val_no_children[0];
+            $object=explode("_", $key);
+            if($object[0]=="location") { $object[0] = "place"; } 
+            $obj=new $object[0]($val);
+            $val_with_children=$obj->get_branch_ids();
+            $val=$val_with_children;
         }
 
         if ($val == "null") {
@@ -123,7 +126,6 @@ function get_photos($vars, $offset, $rows, &$thumbnails, $user = null) {
             $val = escape_string($val);
             $key = escape_string($key);
         }
-
         if ($key == "person" || $key == "photographer") {
             $val = "%" . escape_string(strtolower($val)) . "%";
             
@@ -305,8 +307,30 @@ function get_photos($vars, $offset, $rows, &$thumbnails, $user = null) {
                 $excluded_people["$ppl"] = $val;
                 $excluded_people["${ppl}-conj"] = $conj;
             }
-        }
-        else { // any other field
+        } else if($key == "userrating") {
+            if ($where) { $where .= " AND "; }
+            $ratinguser_id=$vars["_userrating_user"];
+            
+            if(!($ratinguser_id && $user->is_admin())) {
+                $ratinguser_id=$user->get("user_id");
+            }
+            
+            if($val != "null") {
+                $from["pr"]="photo_ratings";
+                $where.=" pr.user_id=" . escape_string($ratinguser_id) .
+                    " AND pr.rating=" . escape_string($val);
+            } else {
+                $no_rate_sql="SELECT DISTINCT(photo_id) FROM " .
+                    DB_PREFIX . "photo_ratings AS pr " .
+                    "WHERE pr.user_id=" . escape_string($ratinguser_id);
+                    
+                $ids = implode(',', get_records_from_query(null, $no_rate_sql));
+
+                if ($ids) {
+                    $where .= "(ph.photo_id not in ($ids))";
+                }
+            }
+        } else { // any other field
 
             if (strncasecmp($key, "field", 5) == 0) {
                 $key = $vars["_" . $key . $suffix];
@@ -365,7 +389,6 @@ function get_photos($vars, $offset, $rows, &$thumbnails, $user = null) {
 
     // do this count separately since the select uses limit
     $query = "select count(distinct ph.photo_id) from $from_clause $where";
-        //echo $query . "\n"; //DEBUG
     $num_photos = get_count_from_query($query);
 
     if ($num_photos > 0) {
@@ -386,7 +409,6 @@ function get_photos($vars, $offset, $rows, &$thumbnails, $user = null) {
                 "select $select from $from_clause $where order by $order " .
                 "limit $offset, $rows";
         }
-        //echo $query . "\n"; //DEBUG
 
         $thumbnails = get_records_from_query("photo", $query);
 
@@ -440,7 +462,6 @@ function generate_excluded_albums_clause($excluded_albums, $from, $where) {
             $photo_id_query .= " and $where";
         }
 
-        //echo $photo_id_query . "\n"; //DEBUG
         $ids = implode(',', get_records_from_query(null, $photo_id_query));
 
         if ($ids) {
@@ -473,7 +494,6 @@ function generate_excluded_categories_clause($excluded_categories, $from, $where
             $photo_id_query .= " and $where";
         }
 
-        //echo $photo_id_query . "\n"; //DEBUG
         $ids = implode(',', get_records_from_query(null, $photo_id_query));
 
         if ($ids) {
@@ -506,7 +526,6 @@ function generate_excluded_people_clause($excluded_people, $from, $where) {
             $photo_id_query .= " and $where";
         }
 
-        //echo $photo_id_query . "\n"; //DEBUG
         $ids = implode(',', get_records_from_query(null, $photo_id_query));
 
         if ($ids) {
