@@ -33,7 +33,7 @@
     }
     require_once("actions.inc.php");
     if (!$user->is_admin() || $action == "display") {
-        header("Location: " . add_sid("places.php?parent_place_id=" . $place->get("place_id")));
+        redirect(add_sid("places.php?parent_place_id=" . $place->get("place_id")));
     }
     if ($action != "insert") {
         $place->lookup();
