@@ -28,7 +28,7 @@
     }
 
     if (!$user->is_admin() && !$user->get("browse_places")) {
-        header("Location: " . add_sid("zoph.php"));
+        redirect(add_sid("zoph.php"));
     }
     $parent_place_id = getvar("parent_place_id");
     if (!$parent_place_id) {
@@ -187,9 +187,9 @@
         if($_view=="tree" && JAVASCRIPT) {
 ?>
             <span class="actionlink">
-                <a href='#' onclick='branchall()'>
+                <a href='#' onclick='expandall()'>
                     <?php echo translate("expand all");?></a> | 
-                <a href='#' onclick='unbranchall()'>
+                <a href='#' onclick='collapseall()'>
                     <?php echo translate("collapse all");?></a>
             </span><br>
 <?php
