@@ -40,7 +40,7 @@
         }
     }
     else {
-        header("Location: " . html_entity_decode(add_sid("photos.php?" . update_query_string($clean_vars, "_off", 0))));
+        redirect(html_entity_decode(add_sid("photos.php?" . update_query_string($clean_vars, "_off", 0))), "No photos");
     }
 
     $newoffset = $offset + 1;
@@ -109,13 +109,13 @@ if (!$_pause) {
         $photo = $thumbnails[0];
         $photo->lookup();
 	?>
-        <div id="prev">&nbsp;</div>
-        <div id="photohdr">
+        <div class="prev">&nbsp;</div>
+        <div class="photohdr">
             <?php echo $photo->get_fullsize_link($photo->get("name"),$FULLSIZE_NEW_WIN)?>: 
             <?php echo $photo->get("width") ?> x <?php echo $photo->get("height")?>,
             <?php echo $photo->get("size") ?> <?php echo translate("bytes")?>
         </div>    
-        <div id="next">&nbsp;</div>
+        <div class="next">&nbsp;</div>
         <?php echo $photo->get_fullsize_link($photo->get_midsize_img(),$FULLSIZE_NEW_WIN)?>
         <?php
         if ($people_links = get_photo_person_links($photo)) {
