@@ -354,7 +354,7 @@ function create_form($vars, $ignore = array()) {
     $form = "";
     while (list($key, $val) = each($vars)) {
         if (in_array($key, $ignore)) { continue; }
-        $form .= "<input type=\"hidden\" name=\"$key\" value=\"$val\">\n";
+        $form .= "<input type=\"hidden\" name=\"$key\" value=\"" . escape_string($val) . "\">\n";
     }
 
     return $form;
@@ -895,4 +895,11 @@ function create_bar_graph($legend, $value_array, $scale) {
     $html.="</table>";
     return $html;
 }
+
+function redirect($url = "zoph.php", $msg = "Access denied") {
+    header("Location: " . $url);
+    echo "<a href='" . $url . "'>" . $msg . "</a>";
+    die();
+}
+
 ?>
