@@ -260,10 +260,17 @@ class zoph_table {
         }
 
         while (list($name, $value) = each($this->fields)) {
-
             if ($this->is_key($name, $keys)) { continue; }
 
             if ($values) { $values .= ", "; }
+            
+            if (substr($name,0,7)=="parent_") {
+                $children=array();
+                $this->get_branch_id_array($children);
+                if(in_array($value, $children)) {
+                    die("You cannot set the parent to a child of the current selection!");
+                } 
+            }
 
             if ($name == "password") {
                 $values .= "$name = password('" . escape_string($value) . "')";
@@ -586,7 +593,14 @@ function get_xml($class, $search,$user=null) {
 
         $xml = new DOMDocument('1.0','UTF-8');
         $rootnode=$xml->createElement($obj->xml_rootname());
-
+        $newchild=$xml->createElement($obj->xml_nodename());
+        $key=$xml->createElement("key");
+        $title=$xml->createElement("title");
+        $key->appendChild($xml->createTextNode("null"));
+        $title->appendChild($xml->createTextNode("&nbsp;"));
+        $newchild->appendChild($key);
+        $newchild->appendChild($title);
+        $rootnode->appendChild($newchild);
 
         if ($tree) {
             $obj = get_root($class);
@@ -598,14 +612,19 @@ function get_xml($class, $search,$user=null) {
                 if($search=="") {
                     $search=null;
                 }
-                if($subclass=="photographer") {
-                    $records=get_photographers($user,$search,true);
+                if($user->is_admin()) {
+                   $records=get_all_people($user,$search, true);
                 } else {
-                    $records=get_photographed_people($user,$search,true);
+                    if($subclass=="photographer") {
+                        $records=get_photographers($user,$search,true);
+                    } else {
+                        $records=get_photographed_people($user,$search,true);
+                    }
                 }
             } else {
                 $records=get_records($class, $order, $constraints, $conj, $ops);
             } 
+           
             foreach($records as $record) {
                 $newchild=$xml->createElement($nodename);
                 $key=$xml->createElement("key");
